@@ -13,7 +13,11 @@ module Rack
       end
 
       def provided?
-        !authorization_key.nil?
+        !authorization_key.nil? && valid?
+      end
+
+      def valid?
+        !@env[authorization_key].nil?
       end
 
       def parts
@@ -21,11 +25,7 @@ module Rack
       end
 
       def scheme
-        @scheme ||=
-          begin
-            s = parts.first.downcase
-            Rack::Auth.schemes.include?(s) ? s.to_sym : s
-          end
+        @scheme ||= parts.first && parts.first.downcase
       end
 
       def params
