@@ -18,6 +18,21 @@ module Rack
     end
     module_function :mime_type
 
+    # Returns true if the given value is a mime match for the given mime match
+    # specification, false otherwise.
+    #
+    #    Rack::Mime.match?('text/html', 'text/*') => true
+    #    Rack::Mime.match?('text/plain', '*') => true
+    #    Rack::Mime.match?('text/html', 'application/json') => false
+
+    def match?(value, matcher)
+      v1, v2 = value.split('/', 2)
+      m1, m2 = matcher.split('/', 2)
+
+      (m1 == '*' || v1 == m1) && (m2.nil? || m2 == '*' || m2 == v2)
+    end
+    module_function :match?
+
     # List of most common mime-types, selected various sources
     # according to their usefulness in a webserving scope for Ruby
     # users.
@@ -30,11 +45,6 @@ module Rack
     #
     # N.B. On Ubuntu the mime.types file does not include the leading period, so
     # users may need to modify the data before merging into the hash.
-    #
-    # To add the list mongrel provides, use:
-    #
-    #     require 'mongrel/handlers'
-    #     Rack::Mime::MIME_TYPES.merge!(Mongrel::DirHandler::MIME_TYPES)
 
     MIME_TYPES = {
       ".123"       => "application/vnd.lotus-1-2-3",
@@ -139,8 +149,11 @@ module Rack
       ".dmg"       => "application/octet-stream",
       ".dna"       => "application/vnd.dna",
       ".doc"       => "application/msword",
+      ".docm"      => "application/vnd.ms-word.document.macroEnabled.12",
       ".docx"      => "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
       ".dot"       => "application/msword",
+      ".dotm"      => "application/vnd.ms-word.template.macroEnabled.12",
+      ".dotx"      => "application/vnd.openxmlformats-officedocument.wordprocessingml.template",
       ".dp"        => "application/vnd.osgi.dp",
       ".dpg"       => "application/vnd.dpgraph",
       ".dsc"       => "text/prs.lines.tag",
@@ -429,10 +442,19 @@ module Rack
       ".pnm"       => "image/x-portable-anymap",
       ".pntg"      => "image/x-macpaint",
       ".portpkg"   => "application/vnd.macports.portpkg",
+      ".pot"       => "application/vnd.ms-powerpoint",
+      ".potm"      => "application/vnd.ms-powerpoint.template.macroEnabled.12",
+      ".potx"      => "application/vnd.openxmlformats-officedocument.presentationml.template",
+      ".ppa"       => "application/vnd.ms-powerpoint",
+      ".ppam"      => "application/vnd.ms-powerpoint.addin.macroEnabled.12",
       ".ppd"       => "application/vnd.cups-ppd",
       ".ppm"       => "image/x-portable-pixmap",
       ".pps"       => "application/vnd.ms-powerpoint",
+      ".ppsm"      => "application/vnd.ms-powerpoint.slideshow.macroEnabled.12",
+      ".ppsx"      => "application/vnd.openxmlformats-officedocument.presentationml.slideshow",
       ".ppt"       => "application/vnd.ms-powerpoint",
+      ".pptm"      => "application/vnd.ms-powerpoint.presentation.macroEnabled.12",
+      ".pptx"      => "application/vnd.openxmlformats-officedocument.presentationml.presentation",
       ".prc"       => "application/vnd.palm",
       ".pre"       => "application/vnd.lotus-freelance",
       ".prf"       => "application/pics-rules",
@@ -599,6 +621,7 @@ module Rack
       ".wmx"       => "video/x-ms-wmx",
       ".wmz"       => "application/x-ms-wmz",
       ".woff"      => "application/font-woff",
+      ".woff2"     => "application/font-woff2",
       ".wpd"       => "application/vnd.wordperfect",
       ".wpl"       => "application/vnd.ms-wpl",
       ".wps"       => "application/vnd.ms-works",
@@ -622,8 +645,14 @@ module Rack
       ".xfdl"      => "application/vnd.xfdl",
       ".xhtml"     => "application/xhtml+xml",
       ".xif"       => "image/vnd.xiff",
+      ".xla"       => "application/vnd.ms-excel",
+      ".xlam"      => "application/vnd.ms-excel.addin.macroEnabled.12",
       ".xls"       => "application/vnd.ms-excel",
+      ".xlsb"      => "application/vnd.ms-excel.sheet.binary.macroEnabled.12",
       ".xlsx"      => "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
+      ".xlsm"      => "application/vnd.ms-excel.sheet.macroEnabled.12",
+      ".xlt"       => "application/vnd.ms-excel",
+      ".xltx"      => "application/vnd.openxmlformats-officedocument.spreadsheetml.template",
       ".xml"       => "application/xml",
       ".xo"        => "application/vnd.olpc-sugar",
       ".xop"       => "application/xop+xml",
